@@ -10,12 +10,15 @@ Copyright (c) 2012 Multmeio [design+tecnologia]. All rights reserved.
 from django.template.defaultfilters import slugify, floatformat
 from django.db import connection
 from ast import literal_eval
+from datetime import datetime
 
 __all__ = ['single_list_to_tuple',
            'str2literal',
            'dec2real',
            'has_any_in',
-           'dynamic_field_table_exists'
+           'dynamic_field_table_exists',
+           'str2date',
+           'str2datetime',
 ]
 
 
@@ -31,16 +34,27 @@ def str2literal(string):
 def dec2real(value):
     return floatformat(value, 2)
 
+def str2datetime(value, format="%Y-%m-%d %H:%M:%S.%f"):
+    try:
+        return datetime.strptime(
+            value, format
+        )
+    except:
+        return ''
+
+def str2date(value):
+    try:
+        return str2datetime(value, "%Y-%m-%d").date()
+    except:
+        return ''
+
 def has_any_in(chances, possibilities):
     return any([x for x in chances if x in possibilities])
 
 # cache in globals
 _DYNAMIC_FIELD_TABLE_EXISTS = None
 def dynamic_field_table_exists():
-    # NOTE: Error happen on syncdb, because DynamicField's table does not exist.
     global _DYNAMIC_FIELD_TABLE_EXISTS
-    if _DYNAMIC_FIELD_TABLE_EXISTS == None:
-        cursor = connection.cursor()
-        cursor.execute("select count(*) from pg_tables where tablename='dynamic_field'")
-        _DYNAMIC_FIELD_TABLE_EXISTS = cursor.fetchone()[0] > 0
+    if not _DYNAMIC_FIELD_TABLE_EXISTS:
+        _DYNAMIC_FIELD_TABLE_EXISTS = 'dynamic_field' in connection.introspection.table_names()
     return _DYNAMIC_FIELD_TABLE_EXISTS
